# QNNGDS

## Description
QNNGDS is a toolbox built on top of phidl for device design in the QNN group.
It is made for helping in the design of gds files. The package is composed of 5 main modules:
- design (contains pre-built cells, ready to be added to a design)
- utilities (contains useful functions for building a new cell)
- geometries (contains test structures and geometry tools)
- circuits (contains circuits made of devices)
- devices (contains devices like ntron, htron, snspd)

## Getting Started
### Installing
- Make sure [gdspy](https://pypi.org/project/gdspy/) is installed
- Install qnngds package with 'pip install qnngds'

### Dependencies
- [phidl](https://pypi.org/project/phidl/)
- [scipy](https://pypi.org/project/scipy/)

## License
This project is licensed under the MIT License - see the LICENSE.txt file for details

## [Documentation](https://qnngds.readthedocs.io/en/latest/)
- [API](https://qnngds.readthedocs.io/en/latest/api.html)
- [Tutorials](https://qnngds.readthedocs.io/en/latest/tutorials.html)

## How to contribute
- [Developer's documentation](https://qnngds-dev.readthedocs.io/en/latest)
